@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc 1099 2007-09-27 15:23:49Z arminb $ -*- c++ -*-
+//$Id: examplewindow.cc 726 2004-09-19 12:55:53Z murrayc $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -27,25 +27,7 @@ ExampleWindow::ExampleWindow()
   set_border_width(10);
 
   //Get Glade UI:
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-  {
-    m_refGlade = Gnome::Glade::Xml::create("example.glade");
-  }
-  catch(const Gnome::Glade::XmlError& ex)
-  {
-    std::cerr << ex.what() << std::endl;
-    return;
-  }
-#else
-  std::auto_ptr<Gnome::Glade::XmlError> error;
-  m_refGlade = Gnome::Glade::Xml::create("example.glade", "", "", error);
-  if(error.get())
-  {
-    std::cerr << error->what() << std::endl;
-    return;
-  }
-#endif
+  m_refGlade = Gnome::Glade::Xml::create("example.glade");
   m_refGlade->reparent_widget("vbox", *this);
 
   m_pVariablesMap = new Gnome::Glade::VariablesMap(m_refGlade);
